pub fn get_native_encoding_name() -> Result<&'static str, NativeEncodingError>Expand description
Returns the canonical label for the native system encoding.
Errors
Returns NativeEncodingError if the system encoding cannot be detected.
pub fn get_native_encoding_name() -> Result<&'static str, NativeEncodingError>Returns the canonical label for the native system encoding.
Returns NativeEncodingError if the system encoding cannot be detected.